==> all-in-one-wp-migration.6.68.zip: all-in-one-wp-migration/loader.php <==
<?php
/**
 * Copyright (C) 2014-2018 ServMask Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ███████╗███████╗██████╗ ██╗   ██╗███╗   ███╗ █████╗ ███████╗██╗  ██╗
 * ██╔════╝██╔════╝██╔══██╗██║   ██║████╗ ████║██╔══██╗██╔════╝██║ ██╔╝
 * ███████╗█████╗  ██████╔╝██║   ██║██╔████╔██║███████║███████╗█████╔╝
 * ╚════██║██╔══╝  ██╔══██╗╚██╗ ██╔╝██║╚██╔╝██║██╔══██║╚════██║██╔═██╗
 * ███████║███████╗██║  ██║ ╚████╔╝ ██║ ╚═╝ ██║██║  ██║███████║██║  ██╗
 * ╚══════╝╚══════╝╚═╝  ╚═╝  ╚═══╝  ╚═╝     ╚═╝╚═╝  ╚═╝╚══════╝╚═╝  ╚═╝
 */

// include all the files that you want to load in here
require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'bandar' .
			DIRECTORY_SEPARATOR .
			'bandar' .
			DIRECTORY_SEPARATOR .
			'lib' .
			DIRECTORY_SEPARATOR .
			'Bandar.php';


if ( class_exists( 'WP_CLI' ) ) {
	require_once AI1WM_VENDOR_PATH .
				DIRECTORY_SEPARATOR .
				'servmask' .
				DIRECTORY_SEPARATOR .
				'command' .
				DIRECTORY_SEPARATOR .
				'class-ai1wm-wp-cli-command.php';
}

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-directory.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-index.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-htaccess.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-webconfig.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'cron' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-cron.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'iterator' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-directory-iterator.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-extension-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-exclude-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-newline-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-archiver.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-compressor.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-extractor.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-mysql.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-mysqli.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-utility.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'math' .
			DIRECTORY_SEPARATOR .
			'BigInteger.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-main-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-status-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-resolve-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-backups-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-updater-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-feedback-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-report-controller.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-init.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-compatibility.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-resolve.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-archive.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-config.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-enumerate.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-content.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-database.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-database-file.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-download.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-clean.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-compatibility.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-upload.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-resolve.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-validate.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-blogs.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-confirm.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-enumerate.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-content.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-mu-plugins.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-database.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-done.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-clean.php';

require_once AI1WM_HTTP_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-http-abstract.php';

require_once AI1WM_HTTP_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-http-stream.php';

require_once AI1WM_HTTP_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-http-curl.php';

require_once AI1WM_HTTP_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-http-factory.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-deprecated.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-extensions.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-compatibility.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-backups.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-updater.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-feedback.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-report.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-template.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-status.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-log.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-message.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-notification.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-handler.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-http.php';

==> all-in-one-wp-migration.6.80.zip: all-in-one-wp-migration/loader.php <==
<?php
/**
 * Copyright (C) 2014-2018 ServMask Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ███████╗███████╗██████╗ ██╗   ██╗███╗   ███╗ █████╗ ███████╗██╗  ██╗
 * ██╔════╝██╔════╝██╔══██╗██║   ██║████╗ ████║██╔══██╗██╔════╝██║ ██╔╝
 * ███████╗█████╗  ██████╔╝██║   ██║██╔████╔██║███████║███████╗█████╔╝
 * ╚════██║██╔══╝  ██╔══██╗╚██╗ ██╔╝██║╚██╔╝██║██╔══██║╚════██║██╔═██╗
 * ███████║███████╗██║  ██║ ╚████╔╝ ██║ ╚═╝ ██║██║  ██║███████║██║  ██╗
 * ╚══════╝╚══════╝╚═╝  ╚═╝  ╚═══╝  ╚═╝     ╚═╝╚═╝  ╚═╝╚══════╝╚═╝  ╚═╝
 */

// Include all the files that you want to load in here
require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'bandar' .
			DIRECTORY_SEPARATOR .
			'bandar' .
			DIRECTORY_SEPARATOR .
			'lib' .
			DIRECTORY_SEPARATOR .
			'Bandar.php';


if ( defined( 'WP_CLI' ) ) {
	require_once AI1WM_VENDOR_PATH .
				DIRECTORY_SEPARATOR .
				'servmask' .
				DIRECTORY_SEPARATOR .
				'command' .
				DIRECTORY_SEPARATOR .
				'class-ai1wm-wp-cli-command.php';
}

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-directory.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-index.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-htaccess.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filesystem' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-file-webconfig.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'cron' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-cron.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'iterator' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-directory-iterator.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'iterator' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-iterator-iterator.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-extension-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-exclude-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'filter' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-recursive-newline-filter.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-archiver.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-compressor.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'archiver' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-extractor.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-mysql.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-mysqli.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'servmask' .
			DIRECTORY_SEPARATOR .
			'database' .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-database-utility.php';

require_once AI1WM_VENDOR_PATH .
			DIRECTORY_SEPARATOR .
			'math' .
			DIRECTORY_SEPARATOR .
			'BigInteger.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-main-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-status-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-backups-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-updater-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-feedback-controller.php';

require_once AI1WM_CONTROLLER_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-report-controller.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-init.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-compatibility.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-archive.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-config.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-config-file.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-enumerate.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-content.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-database.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-database-file.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-download.php';

require_once AI1WM_EXPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-export-clean.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-compatibility.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-upload.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-validate.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-blogs.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-confirm.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-enumerate.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-content.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-mu-plugins.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-database.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-done.php';

require_once AI1WM_IMPORT_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-import-clean.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-deprecated.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-extensions.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-compatibility.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-backups.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-updater.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-feedback.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-report.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-template.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-status.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-log.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-message.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-notification.php';

require_once AI1WM_MODEL_PATH .
			DIRECTORY_SEPARATOR .
			'class-ai1wm-handler.php';
